@@ -12,7 +12,7 @@ use HTTP::Exception '4XX';
 use JSON::XS;
 use YAML::Syck;
 
-our $VERSION = '0.05'; # is set automagically with Milla
+our $VERSION = '0.06'; # is set automagically with Milla
 
 ### Try load library
 sub _try_load {
@@ -125,9 +125,7 @@ sub _getAccept {
 		}
 	}
 
-	HTTP::Exception::406->throw() unless defined $accept;
-
-	return $accept;
+	return ($accept||'application/json');
 }
 
 1;
@@ -252,4 +250,4 @@ Copyright 2015- Václav Dovrtěl
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
